pub enum Call<T>{
set_status {
who: T::AccountId,
status: Status,
},
// some variants omitted
}Expand description
Contains a variant per dispatchable extrinsic that this pallet has.
Variants
set_status
Sets the status of a specific account.
This function allows a protected origin to update the status of an account. It is typically used for management tasks, such as managing account states during runtime upgrades or other administrative actions.
The status of the account will be updated to the provided status value.
Arguments:
origin: The origin of the transaction (must be the root account).who: TheAccountIdof the account whose status is being set.status: The newStatusto assign to the account.
Implementations